This function provides the Cox-Snell diagnostic plot for fitting for Bayesian beta regression models.
cox.snell.beta4reg(x, ncurves = 10, CI = 0.95, PLOT = TRUE)an object obtained from the function beta4reg.
the number of posterior draws.
the level of confidence for point-wise credible intervals.
a logical value indicating whether the Cox-Snell residuals will be plotted.
The function returns the plot (if PLOT = TRUE) and a list with the following components:
the x-axis values with length, say ngrid
the ngrid by 1 averaged cumulative hazard values across the nsave posterior samples
the ngrid by 1 lower bound cumulative hazard values
the ngrid by 1 upper bound cumulative hazard values
the ngrid by nsave cumulative hazard values